==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/ListPrivateCloudAdminCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property privateCloudName Name of the private cloud
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListPrivateCloudAdminCredentialsPlainArgs(
    public val privateCloudName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs =
        com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs.builder()
            .privateCloudName(privateCloudName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListPrivateCloudAdminCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListPrivateCloudAdminCredentialsPlainArgsBuilder internal constructor() {
    private var privateCloudName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the private cloud
     */
    @JvmName("tngeqpisyevhtbdw")
    public suspend fun privateCloudName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateCloudName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("duexgtebmlbcfdso")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListPrivateCloudAdminCredentialsPlainArgs =
        ListPrivateCloudAdminCredentialsPlainArgs(
            privateCloudName = privateCloudName ?: throw PulumiNullFieldException("privateCloudName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/ListPrivateCloudAdminCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property privateCloudName Name of the private cloud
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListPrivateCloudAdminCredentialsPlainArgs(
    public val privateCloudName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs =
        com.pulumi.azurenative.avs.inputs.ListPrivateCloudAdminCredentialsPlainArgs.builder()
            .privateCloudName(privateCloudName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListPrivateCloudAdminCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListPrivateCloudAdminCredentialsPlainArgsBuilder internal constructor() {
    private var privateCloudName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the private cloud
     */
    @JvmName("bkhnqkjxlotppgsp")
    public suspend fun privateCloudName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateCloudName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ugonhtbxotplvvot")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListPrivateCloudAdminCredentialsPlainArgs =
        ListPrivateCloudAdminCredentialsPlainArgs(
            privateCloudName = privateCloudName ?: throw PulumiNullFieldException("privateCloudName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
